@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.12";
+our $VERSION = "1.13";
 
 use v5.14;
 use warnings;
@@ -25,45 +25,45 @@ use Getopt::EX::Hashed; {
 
     Getopt::EX::Hashed->configure( DEFAULT => [ is => 'ro' ] );
 
-    has debug               => spec => '         ' ;
-    has help                => spec => '    h    ' ;
-    has version             => spec => '    v    ' ;
-    has width               => spec => ' =s c    ' ;
-    has fillrows            => spec => '    x    ' ;
-    has table               => spec => '    t    ' ;
-    has table_columns_limit => spec => ' =i l    ' , default => 0 ;
-    has table_right         => spec => ' =s R    ' , default => '' ;
-    has separator           => spec => ' =s s    ' , default => ' ' ;
-    has output_separator    => spec => ' =s o    ' , default => '  ' ;
-    has document            => spec => '    D    ' ;
-    has page                => spec => ' :i P    ' , min => 0;
-    has pane                => spec => ' =i C    ' , min => 1, default => 0 ;
-    has pane_width          => spec => ' =s S pw ' , min => 1;
-    has fullwidth           => spec => ' !  F    ' ;
-    has paragraph           => spec => ' !  p    ' ;
-    has height              => spec => ' =s      ' , default => 0 ;
-    has column_unit         => spec => ' =i   cu ' , min => 1, default => 8 ;
-    has tabstop             => spec => ' =i      ' , min => 1, default => 8 ;
-    has tabhead             => spec => ' =s      ' ;
-    has tabspace            => spec => ' =s      ' ;
-    has tabstyle            => spec => ' =s      ' ;
-    has ignore_space        => spec => ' !    is ' , default => 1 ;
-    has linestyle           => spec => ' =s   ls ' , default => '' ;
-    has boundary            => spec => ' =s      ' , default => '' ;
-    has linebreak           => spec => ' =s   lb ' , default => '' ;
-    has runin               => spec => ' =i      ' , min => 1, default => 2 ;
-    has runout              => spec => ' =i      ' , min => 1, default => 2 ;
-    has pagebreak           => spec => ' !       ' , default => 1 ;
-    has border              => spec => ' :s      ' ;
-    has border_style        => spec => ' =s   bs ' , default => 'vbar' ;
-    has white_space         => spec => ' !       ' , default => 2 ;
-    has isolation           => spec => ' !       ' , default => 2 ;
-    has fillup              => spec => ' :s      ' ;
-    has fillup_str          => spec => ' :s      ' , default => '' ;
-    has ambiguous           => spec => ' =s      ' , default => 'narrow' ;
-    has discard_el          => spec => ' !       ' , default => 1 ;
-    has padchar             => spec => ' =s      ' , default => ' ' ;
-    has colormap            => spec => ' =s@  cm ' , default => [] ;
+    has debug               => '         ' ;
+    has help                => '    h    ' ;
+    has version             => '    v    ' ;
+    has width               => ' =s c    ' ;
+    has fillrows            => '    x    ' ;
+    has table               => '    t    ' ;
+    has table_columns_limit => ' =i l    ' , default => 0 ;
+    has table_right         => ' =s R    ' , default => '' ;
+    has separator           => ' =s s    ' , default => ' ' ;
+    has output_separator    => ' =s o    ' , default => '  ' ;
+    has document            => '    D    ' ;
+    has page                => ' :i P    ' , min => 0;
+    has pane                => ' =i C    ' , min => 1, default => 0 ;
+    has pane_width          => ' =s S pw ' , min => 1;
+    has fullwidth           => ' !  F    ' ;
+    has paragraph           => ' !  p    ' ;
+    has height              => ' =s      ' , default => 0 ;
+    has column_unit         => ' =i   cu ' , min => 1, default => 8 ;
+    has tabstop             => ' =i      ' , min => 1, default => 8 ;
+    has tabhead             => ' =s      ' ;
+    has tabspace            => ' =s      ' ;
+    has tabstyle            => ' =s      ' ;
+    has ignore_space        => ' !    is ' , default => 1 ;
+    has linestyle           => ' =s   ls ' , default => '' ;
+    has boundary            => ' =s      ' , default => '' ;
+    has linebreak           => ' =s   lb ' , default => '' ;
+    has runin               => ' =i      ' , min => 1, default => 2 ;
+    has runout              => ' =i      ' , min => 1, default => 2 ;
+    has pagebreak           => ' !       ' , default => 1 ;
+    has border              => ' :s B    ' ;
+    has border_style        => ' =s   bs ' , default => 'vbar' ;
+    has white_space         => ' !       ' , default => 2 ;
+    has isolation           => ' !       ' , default => 2 ;
+    has fillup              => ' :s      ' ;
+    has fillup_str          => ' :s      ' , default => '' ;
+    has ambiguous           => ' =s      ' , default => 'narrow' ;
+    has discard_el          => ' !       ' , default => 1 ;
+    has padchar             => ' =s      ' , default => ' ' ;
+    has colormap            => ' =s@  cm ' , default => [] ;
 
     has '+boundary'  => re => qr/^(none|word|space)$/;
     has '+linestyle' => re => qr/^(none|wordwrap|wrap|truncate)$/;
